from django import template
from django.core.cache import cache

from config.cache_durations import *
from gallery.cache import cached_or_set
from gallery.models import Album, Photo

register = template.Library()


@register.simple_tag
def gallery_stats():
    """
    Returns a tuple with (total albums, public albums, total photos).
    Result is cached for GALLERY_STATS_DURATION.
    """
    return cached_or_set(
        "gallery_stats",
        GALLERY_STATS_DURATION,
        lambda: (
            Album.objects.count(),
            Album.objects.filter(is_public=True).count(),
            Photo.objects.count()
        )
    )
